"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.library = exports.recursiveObject2 = exports.recursiveObject = void 0;
/**
 * This file exists and is package exported to aid in testing of exporting recursive types across package boundaries.
 * Sometimes when TypeScript generates d.ts files, they type check significantly differently than the original source (One example of this: https://github.com/microsoft/TypeScript/issues/20979).
 * Unfortunately our recursive schema types are an example of types that have this kind of issue: the d.ts files tend to get "any" instead of the recursive type reference.
 * Currently we do not have tooling in place to test this in our test suite, and exporting these types here is a temporary crutch to aid in diagnosing this issue.
 */
const feature_libraries_1 = require("../feature-libraries");
const leafDomain_1 = require("./leafDomain");
const builder = new feature_libraries_1.SchemaBuilderBase(feature_libraries_1.FieldKinds.optional, { scope: "Test Recursive Domain" });
exports.recursiveObject = builder.objectRecursive("object", {
    recursive: feature_libraries_1.TreeFieldSchema.createUnsafe(feature_libraries_1.FieldKinds.optional, [() => exports.recursiveObject]),
    number: leafDomain_1.leaf.number,
});
function fixRecursiveReference(...types) { }
const recursiveReference = () => exports.recursiveObject2;
fixRecursiveReference(recursiveReference);
exports.recursiveObject2 = builder.object("object2", {
    recursive: feature_libraries_1.TreeFieldSchema.create(feature_libraries_1.FieldKinds.optional, [recursiveReference]),
    number: leafDomain_1.leaf.number,
});
exports.library = builder.intoLibrary();
{
    const b = new feature_libraries_1.SchemaBuilderBase(feature_libraries_1.FieldKinds.optional, { scope: "Test Recursive Domain" });
    const node = b.objectRecursive("object", {
        child: feature_libraries_1.TreeFieldSchema.createUnsafe(feature_libraries_1.FieldKinds.optional, [() => node]),
    });
    const _field = feature_libraries_1.TreeFieldSchema.createUnsafe(feature_libraries_1.FieldKinds.optional, [node]);
    // All these cause TSC to "RangeError: Maximum call stack size exceeded"
    // const _field4 = TreeFieldSchema.create(FieldKinds.optional, [node]);
    // const _field2 = b.optional(node);
    // const _field3 = SchemaBuilder.optional(node);
    // const schema = b.intoSchema(field);
    // const schema = b.intoSchema(_field);
}
//# sourceMappingURL=testRecursiveDomain.js.map