"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeForestSummarizerCodec = void 0;
const core_utils_1 = require("@fluidframework/core-utils");
const versioned_1 = require("../versioned");
const format_1 = require("./format");
function makeForestSummarizerCodec(options, fieldBatchCodec) {
    // TODO: every time context changes, withSchemaValidation and makeVersionedCodec recompile their json validators.
    // Those should be reused. Making more code context aware could fix that.
    return (context) => {
        const inner = fieldBatchCodec(context);
        return (0, versioned_1.makeVersionedValidatedCodec)(options, new Set([1]), format_1.Format, {
            encode: (data) => {
                const keys = [];
                const fields = [];
                for (const [key, value] of data) {
                    keys.push(key);
                    fields.push(value);
                }
                return { keys, fields: inner.encode(fields), version: 1 };
            },
            decode: (data) => {
                const out = new Map();
                const fields = inner.decode(data.fields);
                (0, core_utils_1.assert)(data.keys.length === fields.length, "mismatched lengths");
                for (let index = 0; index < fields.length; index++) {
                    out.set(data.keys[index], fields[index]);
                }
                return out;
            },
        });
    };
}
exports.makeForestSummarizerCodec = makeForestSummarizerCodec;
//# sourceMappingURL=codec.js.map