/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { TSchema } from "@sinclair/typebox";
import { JsonCompatibleReadOnly } from "../util";
import { EncodedRevisionTag } from "../core";
/**
 * The format of messages that SharedTree sends and receives.
 */
export interface Message {
    /**
     * The revision tag for the change in this message
     */
    readonly revision: EncodedRevisionTag;
    /**
     * The stable ID that identifies the originator of the message.
     */
    readonly originatorId: string;
    /**
     * The changeset to be applied.
     */
    readonly changeset: JsonCompatibleReadOnly;
}
export declare const Message: <ChangeSchema extends TSchema>(tChange: ChangeSchema) => import("@sinclair/typebox").TObject<{
    revision: import("@sinclair/typebox").TUnsafe<EncodedRevisionTag>;
    originatorId: import("@sinclair/typebox").TUnsafe<string>;
    changeset: ChangeSchema;
}>;
//# sourceMappingURL=messageFormat.d.ts.map