/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { disposeSymbol } from "../util";
import { getProxyForField } from "../simple-tree";
/**
 * Configuration for how to {@link ITree.schematize|schematize} a tree.
 * @beta
 */
export class TreeConfiguration {
    /**
     * @param schema - The schema which the application wants to view the tree with.
     * @param initialTree - A function that returns the default tree content to initialize the tree with iff the tree is uninitialized
     * (meaning it does not even have any schema set at all).
     * If `initialTree` returns any actual node instances, they should be recreated each time `initialTree` runs.
     * This is because if the config is used a second time any nodes that were not recreated could error since nodes cannot be inserted into the tree multiple times.
     */
    constructor(schema, initialTree) {
        this.schema = schema;
        this.initialTree = initialTree;
    }
}
/**
 * Implementation of TreeView wrapping a FlexTreeView.
 */
export class WrapperTreeView {
    constructor(view) {
        this.view = view;
    }
    [disposeSymbol]() {
        this.view[disposeSymbol]();
    }
    get events() {
        return this.view.checkout.events;
    }
    get root() {
        return getProxyForField(this.view.editableTree);
    }
}
//# sourceMappingURL=tree.js.map