/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { LeafNodeSchema, Multiplicity, isTreeValue, valueSchemaAllows, } from "../feature-libraries";
// eslint-disable-next-line import/no-internal-modules
import { getFlexNode, tryGetFlexNode } from "../simple-tree/flexNode";
// eslint-disable-next-line import/no-internal-modules
import { getClassSchema, getOrCreateNodeProxy } from "../simple-tree/proxies";
import { schemaFromValue } from "./schemaFactory";
import { getFlexSchema } from "./toFlexSchema";
/**
 * The `Tree` object holds various functions for analyzing {@link TreeNode}s.
 * @beta
 */
export const nodeApi = {
    parent: (node) => {
        const editNode = getFlexNode(node).parentField.parent.parent;
        if (editNode !== undefined) {
            return getOrCreateNodeProxy(editNode);
        }
        return undefined;
    },
    key: (node) => {
        const parentField = getFlexNode(node).parentField;
        if (parentField.parent.schema.kind.multiplicity === Multiplicity.Sequence) {
            // The parent of `node` is a list
            return parentField.index;
        }
        // The parent of `node` is an object, a map, or undefined (and therefore `node` is a root/detached node).
        return parentField.parent.key;
    },
    on: (node, eventName, listener) => {
        return getFlexNode(node).on(eventName, listener);
    },
    status: (node) => {
        return getFlexNode(node).treeStatus();
    },
    is: (value, schema) => {
        const flexSchema = getFlexSchema(schema);
        if (isTreeValue(value)) {
            return (flexSchema instanceof LeafNodeSchema && valueSchemaAllows(flexSchema.info, value));
        }
        return tryGetFlexNode(value)?.is(flexSchema) ?? false;
    },
    schema(node) {
        if (isTreeValue(node)) {
            return schemaFromValue(node);
        }
        return getClassSchema(getFlexNode(node).schema);
    },
};
//# sourceMappingURL=treeApi.js.map