/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { ITreeCursorSynchronous, StoredSchemaCollection } from "../../../core";
import { JsonCompatibleReadOnly } from "../../../util";
import { ICodecOptions, IJsonCodec } from "../../../codec";
import { FullSchemaPolicy } from "../../modular-schema";
import { IJsonCodecWithContext } from "../../../codec/codec";
import { TreeCompressionStrategy } from "../../treeCompressionUtils";
import { EncodedFieldBatch } from "./format";
import { FieldBatch } from "./fieldBatch";
/**
 * Helper for processing multiple fields one at a time.
 */
export declare class FieldBatchEncoder {
    private readonly fields;
    add(field: ITreeCursorSynchronous): number;
    encode(codec: IJsonCodec<FieldBatch, EncodedFieldBatch>): EncodedFieldBatch;
}
export interface Context {
    readonly encodeType: TreeCompressionStrategy;
    readonly schema?: SchemaAndPolicy;
}
export type FieldBatchCodec = IJsonCodecWithContext<FieldBatch, EncodedFieldBatch, JsonCompatibleReadOnly, Context>;
export declare function makeFieldBatchCodec(options: ICodecOptions): IJsonCodecWithContext<FieldBatch, EncodedFieldBatch, JsonCompatibleReadOnly, Context>;
interface SchemaAndPolicy {
    readonly schema: StoredSchemaCollection;
    readonly policy: FullSchemaPolicy;
}
export {};
//# sourceMappingURL=codecs.d.ts.map