/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { assert } from "@fluidframework/core-utils";
import { withSchemaValidation } from "../../codec";
import { Versioned } from "./format";
export function makeVersionedCodec(supportedVersions, { jsonValidator: validator }, inner) {
    return withSchemaValidation(Versioned, {
        encode: (data) => {
            const encoded = inner.encode(data);
            assert(supportedVersions.has(encoded.version), "version being encoded should be supported");
            return encoded;
        },
        decode: (data) => {
            const versioned = data; // Validated by withSchemaValidation
            assert(supportedVersions.has(versioned.version), "version being decoded is not supported");
            const decoded = inner.decode(data);
            return decoded;
        },
    }, validator);
}
export function makeVersionedValidatedCodec(options, supportedVersions, schema, codec) {
    return makeVersionedCodec(supportedVersions, options, withSchemaValidation(schema, codec, options.jsonValidator));
}
//# sourceMappingURL=codec.js.map